pm4py.algo.conformance package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.conformance.alignments
   pm4py.algo.conformance.antialignments
   pm4py.algo.conformance.decomp_alignments
   pm4py.algo.conformance.footprints
   pm4py.algo.conformance.log_skeleton
   pm4py.algo.conformance.logs_alignments
   pm4py.algo.conformance.multialignments
   pm4py.algo.conformance.temporal_profile
   pm4py.algo.conformance.tokenreplay
   pm4py.algo.conformance.tree_alignments

Module contents
---------------

.. automodule:: pm4py.algo.conformance
   :members:
   :undoc-members:
   :show-inheritance:
